@@ -284,7 +284,7 @@ pub fn cmd_stats(gc: Conf, sc: ConfStats) -> Result<bool, Error> {
     cmd_stats_group(&gc, &sc, &mut tblc, &mut tbls, &mut tblp, &mut tblt, group, &run_args,
                     &sync_time, &pkg_time);
     // Controlled drop to ensure table order and insert blank lines
-    let (ec, es, ep, et) = (!tblc.is_empty(), !tbls.is_empty(), !tblp.is_empty(), !tblt.is_empty());
+    let (ec, es, ep, et) = (tblc.has_rows(), tbls.has_rows(), tblp.has_rows(), tblt.has_rows());
     drop(tblc);
     if ec && es {
         println!();
@@ -444,6 +444,7 @@ pub fn cmd_predict(gc: Conf, mut sc: ConfPred) -> Result<bool, Error> {
             proc_rows(now, &mut tbl, &procs, p, 0, &gc, &sc);
         }
     }
+    tbl.header_done();
 
     // Parse emerge log.
     let hist = get_hist(&gc.logfile, gc.from, gc.to, Show::m(), &vec![], false)?;
@@ -583,13 +584,38 @@ pub fn cmd_predict(gc: Conf, mut sc: ConfPred) -> Result<bool, Error> {
     Ok(totcount > 0)
 }
 
+struct Stats {
+    /// Number of values
+    count: usize,
+    /// Minimum value
+    min: f64,
+    /// Minimum value
+    max: f64,
+    /// Arithmetic mean of absolute values
+    arith: f64,
+    /// Standard deviation of values
+    stddev: f64,
+}
+impl Stats {
+    /// Extract basic statistics from float list
+    fn from(vals: &[f64]) -> Self {
+        let arith = vals.iter().copied().map(f64::abs).sum::<f64>() / vals.len() as f64;
+        let variance = vals.iter().map(|&v| (v - arith).powi(2)).sum::<f64>() / vals.len() as f64;
+        Self { count: vals.len(),
+               min: vals.iter().copied().reduce(f64::min).unwrap_or(f64::NAN),
+               max: vals.iter().copied().reduce(f64::max).unwrap_or(f64::NAN),
+               arith,
+               stddev: variance.sqrt() }
+    }
+}
+
 pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
     let hist = get_hist(&gc.logfile, gc.from, gc.to, Show::m(), &sc.search, sc.exact)?;
     let mut pkg_starts: HashMap<String, (i64, bool)> = HashMap::new();
     let mut pkg_times: BTreeMap<(String, bool), Times> = BTreeMap::new();
     let mut pkg_errs: BTreeMap<(String, bool), Vec<f64>> = BTreeMap::new();
-    let mut found = false;
-    let h = ["Date", "Package", "Real", sc.avg.as_str(), "Samples", "Error"];
+    let mut found = 0;
+    let h = ["Date", "Package", "Real", sc.avg.as_str(), "Samples", "Error %"];
     let mut tbl = Table::new(&gc).align_left(0).align_left(1).last(sc.last).header(h);
     for p in hist {
         match p {
@@ -603,7 +629,7 @@ pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
                 }
             },
             Hist::MergeStop { ts, ref key, .. } => {
-                found = true;
+                found += 1;
                 if let Some((start, bin)) = pkg_starts.remove(key) {
                     let times =
                         pkg_times.entry((p.ebuild().to_owned(), bin)).or_insert(Times::new());
@@ -622,7 +648,7 @@ pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
                             }
                         },
                         pred => {
-                            let err = (pred - real).abs() as f64 * 100.0 / real as f64;
+                            let err = (pred - real) as f64 * 100.0 / real as f64;
                             if sc.show.merge {
                                 tbl.row([&[&FmtDate(ts)],
                                          &[if bin { &gc.binmerge } else { &gc.merge },
@@ -630,28 +656,48 @@ pub fn cmd_accuracy(gc: Conf, sc: ConfAccuracy) -> Result<bool, Error> {
                                          &[&FmtDur(real)],
                                          &[&FmtDur(pred)],
                                          &[&gc.cnt, &samples],
-                                         &[&format!("{err:.1}%")]])
+                                         &[&gc.clr, &format!("{err:.1}")]])
                             }
-                            let errs = pkg_errs.entry((p.ebuild().to_owned(), bin)).or_default();
-                            errs.push(err);
+                            pkg_errs.entry((p.ebuild().to_owned(), bin)).or_default().push(err);
                         },
                     }
                     times.insert(real);
                 }
+                if found >= sc.first {
+                    break;
+                }
             },
             e => panic!("Unexpected {e:?}"),
         }
     }
     drop(tbl);
-    if sc.show.tot {
-        let mut tbl = Table::new(&gc).align_left(0).header(["Package", "Error"]);
-        for ((p, b), e) in pkg_errs {
-            let avg = e.iter().sum::<f64>() / e.len() as f64;
+
+    if sc.show.pkg {
+        let h = ["Package", "Estimates", "Min", "Max", "Abs arith mean", "Stddev"];
+        let mut tbl = Table::new(&gc).align_left(0).header(h);
+        for (&(ref p, b), errs) in &pkg_errs {
+            let s = Stats::from(errs);
             tbl.row([&[if b { &gc.binpkg } else { &gc.pkg }, &p],
-                     &[&gc.cnt, &format!("{avg:.1}%")]]);
+                     &[&gc.cnt, &s.count],
+                     &[&gc.clr, &format!("{:.1}", s.min)],
+                     &[&format!("{:.1}", s.max)],
+                     &[&format!("{:.1}", s.arith)],
+                     &[&format!("{:.1}", s.stddev)]]);
         }
     }
-    Ok(found)
+
+    if sc.show.tot {
+        let mut tbl =
+            Table::new(&gc).header(["Estimates", "Min", "Max", "Abs arith mean", "Stddev"]);
+        let errs: Vec<f64> = pkg_errs.iter().flat_map(|(_, e)| e).copied().collect();
+        let s = Stats::from(&errs);
+        tbl.row([&[&gc.cnt, &s.count],
+                 &[&gc.clr, &format!("{:.1}", s.min)],
+                 &[&format!("{:.1}", s.max)],
+                 &[&format!("{:.1}", s.arith)],
+                 &[&format!("{:.1}", s.stddev)]]);
+    }
+    Ok(found > 0)
 }
 
 pub fn cmd_complete(gc: Conf, sc: ConfComplete) -> Result<bool, Error> {
@@ -671,7 +717,7 @@ pub fn cmd_complete(gc: Conf, sc: ConfComplete) -> Result<bool, Error> {
         if let Hist::MergeStart { .. } = p {
             let e = p.take_ebuild();
             if !pkgs.contains(&e) {
-                println!("{}", e);
+                println!("{e}");
                 pkgs.insert(e);
             }
         }
