@@ -46,12 +46,13 @@ impl Pkg {
 
 /// Parse portage pretend output
 pub fn get_pretend<R: Read>(reader: R, filename: &str) -> Vec<Pkg> {
-    debug!("get_pretend input={}", filename);
+    debug!("get_pretend input={filename}");
     let mut out = vec![];
     let re = Regex::new("^\\[([a-z]+)[^]]*\\] +([^ :\\n]+)").unwrap();
     let mut buf = BufReader::new(reader);
     let mut line = String::new();
     loop {
+        line.clear();
         match buf.read_line(&mut line) {
             // End of file or some other error
             Ok(0) | Err(_) => break,
@@ -70,7 +71,6 @@ pub fn get_pretend<R: Read>(reader: R, filename: &str) -> Vec<Pkg> {
                 }
             },
         }
-        line.clear();
     }
     out
 }
@@ -147,18 +147,9 @@ impl PkgMoves {
         let a = &a.as_bytes()[a.rfind('/').map(|n| n + 1).unwrap_or(0)..];
         let b = &b.as_bytes()[b.rfind('/').map(|n| n + 1).unwrap_or(0)..];
         // If it looks like "Quarter-Year", rewrite it as "YearQuarter"
-        match (a, b) {
-            (&[a0, b'Q', b'-', a1, a2, a3, a4], &[b0, b'Q', b'-', b1, b2, b3, b4]) => {
-                [b1, b2, b3, b4, b0].cmp(&[a1, a2, a3, a4, a0])
-            },
-            (&[a0, b'Q', b'-', a1, a2, a3, a4], _) => b.cmp(&[a1, a2, a3, a4, a0]),
-            (_, &[b0, b'Q', b'-', b1, b2, b3, b4]) => (&[b1, b2, b3, b4, b0] as &[u8]).cmp(a),
-            (_, _) => b.cmp(a),
-        }
-        // TODO MSRV 1.79: simpler version
-        // let a = if let &[q, b'Q', b'-', y1, y2, y3, y4] = a { &[y1, y2, y3, y4, q] } else { a };
-        // let b = if let &[q, b'Q', b'-', y1, y2, y3, y4] = b { &[y1, y2, y3, y4, q] } else { b };
-        // b.cmp(a)
+        let a = if let &[q, b'Q', b'-', y1, y2, y3, y4] = a { &[y1, y2, y3, y4, q] } else { a };
+        let b = if let &[q, b'Q', b'-', y1, y2, y3, y4] = b { &[y1, y2, y3, y4, q] } else { b };
+        b.cmp(a)
     }
 
     /// Load, sort and parse update files
@@ -287,7 +278,7 @@ pub fn get_emerge(procs: &ProcList) -> EmergeInfo {
                      true
                  });
     }
-    trace!("{:?}", res);
+    trace!("{res:?}");
     res
 }
 
@@ -296,13 +287,16 @@ mod tests {
     use super::*;
     use crate::parse::procs;
 
+    impl PartialEq<(&str, &str)> for Pkg {
+        fn eq(&self, p: &(&str, &str)) -> bool {
+            self.ebuild() == p.0 && self.version() == p.1
+        }
+    }
+
     /// Check that `get_pretend()` has the expected output
     fn check_pretend(file: &str, expect: &[(&str, &str)]) {
-        let mut n = 0;
-        for p in get_pretend(File::open(&format!("tests/{file}")).unwrap(), file) {
-            assert_eq!((p.ebuild(), p.version()), expect[n], "Mismatch for {file}:{n}");
-            n += 1;
-        }
+        let parsed: Vec<_> = get_pretend(File::open(&format!("tests/{file}")).unwrap(), file);
+        assert_eq!(&parsed, expect, "failed expect for {file}");
     }
 
     #[test]
